==> haskell-text-builder-0.6.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-builder
version: 0.6.3
id: text-builder-0.6.3-HP0NntOp3VzK5SUNqM0xA
key: text-builder-0.6.3-HP0NntOp3VzK5SUNqM0xA
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/text-builder
synopsis: An efficient strict text builder
category: Text
abi: 5d7983fe6cca17a373574db5f963f21a
exposed: True
exposed-modules:
    Text.Builder
hidden-modules: Text.Builder.UTF16 Text.Builder.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/text-builder-0.6.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/text-builder-0.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/text-builder-0.6.3
hs-libraries: HStext-builder-0.6.3-HP0NntOp3VzK5SUNqM0xA
depends:
    base-4.11.1.0 base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
    bytestring-0.10.8.2 deferred-folds-0.9.7.1-27SrRPzbIbBJsjj3VJjMA3
    text-1.2.3.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deferred-folds-0.9.7.1-27SrRPzbIbBJsjj3VJjMA3=513bf2a922e5aedfe29e81ab8b5486f3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-text-builder/html/text-builder.haddock
haddock-html: /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.4-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-builder
version: 0.6.4
id: text-builder-0.6.4-7YC1qbhaquYKt50nHqwdWc
key: text-builder-0.6.4-7YC1qbhaquYKt50nHqwdWc
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/text-builder
synopsis: An efficient strict text builder
category: Text
abi: 3f647472ea236db2ac70ea10ee9badcb
exposed: True
exposed-modules:
    Text.Builder
hidden-modules: Text.Builder.UTF16 Text.Builder.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/text-builder-0.6.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/text-builder-0.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/text-builder-0.6.4
hs-libraries: HStext-builder-0.6.4-7YC1qbhaquYKt50nHqwdWc
depends:
    base-4.11.1.0 base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
    bytestring-0.10.8.2 deferred-folds-0.9.9-L8CwT3CMBfz2AgOnzyMU7e
    text-1.2.3.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deferred-folds-0.9.9-L8CwT3CMBfz2AgOnzyMU7e=94b669212d9dbf88062fba5397fb444e
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-text-builder/html/text-builder.haddock
haddock-html: /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
